@@ -101,6 +101,7 @@
 \\tempoWholesPerMinute
 \\tempo
 \\teeny
+\\tagGroup
 \\tag
 \\table-of-contents
 \\tablatureFormat
@@ -220,6 +221,7 @@
 \\rtoe
 \\rounded-box
 \\rotate
+\\romanStringNumbers
 \\roman
 \\rightHandFinger
 \\right-column
@@ -348,6 +350,7 @@
 \\octaveCheck
 \\numericTimeSignature
 \\number
+\\nullAccidentals
 \\null
 \\notemode
 \\noteToFretFunction
@@ -460,14 +463,15 @@
 \\instrumentSwitch
 \\instrumentName
 \\instrumentEqualizer
+\\initialTimeSignatureVisibility
 \\indent
 \\include
 \\inclinatum
+\\incipit
 \\inStaffSegno
 \\in
 \\improvisationOn
 \\improvisationOff
-\\implicitTimeSignatureVisibility
 \\ij
 \\iij
 \\ignoreFiguredBassRest
@@ -521,6 +525,7 @@
 \\flat
 \\flageolet
 \\firstClef
+\\first-visible
 \\fingeringOrientations
 \\finger
 \\finalis
@@ -549,7 +554,6 @@
 \\epsfile
 \\episemInitium
 \\episemFinis
-\\endincipit
 \\enddim
 \\enddecresc
 \\enddecr
@@ -713,7 +717,13 @@
 \\backslashed-digit
 \\automaticBars
 \\autochange
+\\autoPageBreaksOn
+\\autoPageBreaksOff
+\\autoLineBreaksOn
+\\autoLineBreaksOff
 \\autoCautionaries
+\\autoBreaksOn
+\\autoBreaksOff
 \\autoBeaming
 \\autoBeamOn
 \\autoBeamOff
@@ -722,6 +732,7 @@
 \\auto-footnote
 \\augmentum
 \\auctum
+\\associatedVoiceType
 \\assertBeamSlope
 \\assertBeamQuant
 \\ascendens
@@ -733,6 +744,7 @@
 \\arpeggioArrowUp
 \\arpeggioArrowDown
 \\arpeggio
+\\arabicStringNumbers
 \\appoggiatura
 \\applyOutput
 \\applyMusic
@@ -1060,8 +1072,6 @@ gx
 gtqs
 gtqf
 gss
-gsharpsharp
-gsharp
 gs
 gqs
 gqf
@@ -1071,8 +1081,6 @@ gisis
 gisih
 gis
 gih
-gflatflat
-gflat
 gff
 gf
 gessess
@@ -1086,8 +1094,6 @@ fx
 ftqs
 ftqf
 fss
-fsharpsharp
-fsharp
 fs
 fqs
 fqf
@@ -1097,8 +1103,6 @@ fisis
 fisih
 fis
 fih
-fflatflat
-fflat
 fff
 ff
 fessess
@@ -1135,8 +1139,6 @@ etqs
 etqf
 essess
 ess
-esharpsharp
-esharp
 eses
 eseh
 es
@@ -1148,8 +1150,6 @@ eisis
 eisih
 eis
 eih
-eflatflat
-eflat
 eff
 ef
 eessess
@@ -1163,8 +1163,6 @@ dx
 dtqs
 dtqf
 dss
-dsharpsharp
-dsharp
 ds
 dqs
 dqf
@@ -1196,8 +1194,6 @@ disis
 disih
 dis
 dih
-dflatflat
-dflat
 dff
 df
 dessess
@@ -1211,8 +1207,6 @@ cx
 ctqs
 ctqf
 css
-csharpsharp
-csharp
 cs
 cqs
 cqf
@@ -1222,8 +1216,6 @@ cisis
 cisih
 cis
 cih
-cflatflat
-cflat
 cff
 cf
 cessess
@@ -1237,8 +1229,6 @@ bx
 btqs
 btqf
 bss
-bsharpsharp
-bsharp
 bs
 bqs
 bqf
@@ -1246,8 +1236,6 @@ bisis
 bisih
 bis
 bih
-bflatflat
-bflat
 bff
 bf
 bess
@@ -1262,8 +1250,6 @@ atqs
 atqf
 assess
 ass
-asharpsharp
-asharp
 ases
 aseh
 asas
@@ -1277,8 +1263,6 @@ aisis
 aisih
 ais
 aih
-aflatflat
-aflat
 aff
 af
 aessess
